/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Quickfile extension for Thunderbird.
 *
 * The Initial Developer of the Original Code is Paul Tomlin.
 * Portions created by the Initial Developer are Copyright (C) 2005, 2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Paul Tomlin
 *  Mark Shuttleworth
 *
 * ***** END LICENSE BLOCK ***** */

/* $Id: common.js,v 1.2 2006/11/20 10:32:31 paultomlin Exp $ */

// static import interfaces
//const nsIDictionary                     = Components.interfaces.nsIDictionary;
const nsICategoryManager                = Components.interfaces.nsICategoryManager;
const nsIMessenger                      = Components.interfaces.nsIMessenger;
const nsIMsgAccount                     = Components.interfaces.nsIMsgAccount;
const nsIMsgAccountManager              = Components.interfaces.nsIMsgAccountManager;
//const nsIMsgDBHdr                       = Components.interfaces.nsIMsgDBHdr;
const nsIMsgFolder                      = Components.interfaces.nsIMsgFolder;
const nsIMsgCopyService                 = Components.interfaces.nsIMsgCopyService;
const nsIMsgMailSession                 = Components.interfaces.nsIMsgMailSession;
//const nsIMsgWindow                      = Components.interfaces.nsIMsgWindow;
const nsIPrefService                    = Components.interfaces.nsIPrefService;
const nsIRDFService                     = Components.interfaces.nsIRDFService;
const nsISupports                       = Components.interfaces.nsISupports;
const nsISupportsArray                  = Components.interfaces.nsISupportsArray;
const nsISupportsString                 = Components.interfaces.nsISupportsString;
const nsIUrlListener                    = Components.interfaces.nsIUrlListener;
const nsMsgNavigationType               = Components.interfaces.nsMsgNavigationType;

const NS_ERROR_INVALID_ARG              = Components.results.NS_ERROR_INVALID_ARG;

const QF_SEARCHROOT_ALL                 = 'msgaccounts:/';
const QF_SEARCHROOT_ACCOUNT             = 'msgaccount:/';

var QuickfileCommon =
{
  _debug: true,

  /**
   *
   */
  log: function _log (aString)
  {
    if (this._debug)
      dump(aString + "\n");
  },

  /**
   * Ripped from mail/base/content/widgetgloue.js
   *
   * @param aUri the URI of the resource you seek
   * @return an RDF resource
   */
  getResourceFromURI: function _getResourceFromURI (aUri) {
    var RDF = Components.classes['@mozilla.org/rdf/rdf-service;1']
                        .getService()
                        .QueryInterface(nsIRDFService);

    return RDF.GetResource(aUri);
  },

  /**
   * Ripped from mail/base/content/widgetglue.js
   *
   * @param aUri the URI of the folder you seek
   * @return nsIMsgFolder
   * @todo is this possible via XPCOM instead of RDF?
   */
  getFolderFromURI: function _getFolderFromURI (aUri) {
    var msgfolder = null;
    try {
      var resource = this.getResourceFromURI(aUri);
      msgfolder = resource.QueryInterface(nsIMsgFolder);
    }
    catch (ex) {
      dump("failed to get the folder resource for " + aUri + "\n");
    }
    return msgfolder;
  },

  /**
   * Get the user friendly name of the folder, relative to a parent
   *
   * @param aFolder  an nsIMsgFolder to get the name of
   * @param aRelativeParent  an nsIMsgFolder that's a parent of aFolder, at which
   *                         to stop looking up names. If null then assume root.
   */
//  getFolderFullName: function _getFolderFullName (aFolder, aRelativeParent)
  getFolderRelativeName: function _getFolderRelativeName (aFolder, aRelativeParent)
  {
    this.log("QuickfileCommon::getFolderRelativeName(" + aFolder.name + ", " + aRelativeParent + ")");

    if (aRelativeParent && ! aRelativeParent.isAncestorOf(aFolder))
      throw NS_ERROR_INVALID_ARG;

    if (aFolder.parent && aFolder.parent != aRelativeParent)
      return this.getFolderRelativeName(aFolder.parent, aRelativeParent) + '/' + aFolder.name;
    else
      return aFolder.name;
  }
};
